@@ -108,7 +108,7 @@ type_as_function ## _factory_create_accessible (GObject *obj)			\
 {										\
   AtkObject *accessible;							\
 										\
-  g_return_val_if_fail (G_IS_OBJECT (obj), NULL);				\
+  g_assert (G_IS_OBJECT (obj));  						\
 										\
   accessible = opt_create_accessible (obj);					\
 										\
