@@ -43,10 +43,10 @@
 
 /* Pack RGBA values into 32 bits */
 #define EEL_RGBA_COLOR_PACK(r, g, b, a)		\
-( ((a) << 24) |					\
-  ((r) << 16) |					\
-  ((g) <<  8) |					\
-  ((b) <<  0) )
+( (((guint32)a) << 24) |			\
+  (((guint32)r) << 16) |			\
+  (((guint32)g) <<  8) |			\
+  (((guint32)b) <<  0) )
 
 /* Pack opaque RGBA values into 32 bits */
 #define EEL_RGB_COLOR_PACK(r, g, b)		\
@@ -121,10 +121,6 @@ char *              eel_gdk_rgb_to_color_spec              (guint32
 gboolean            eel_gdk_color_parse                    (const gchar         *spec,
 							    GdkColor            *color);
 
-/* Fill routines that take GdkRectangle parameters instead of four integers. */
-void                eel_fill_rectangle                     (GdkDrawable         *drawable,
-							    GdkGC               *gc,
-							    const GdkRectangle  *rectangle);
 gboolean            eel_gdk_color_is_dark                  (GdkColor            *color);
 
 /* A routine to get a 50% gray stippled bitmap for use in some types of highlighting. */
@@ -133,14 +129,8 @@ GdkBitmap *         eel_stipple_bitmap                     (void);
 
 
 /* Misc GdkRectangle helper functions */
-gboolean            eel_rectangle_contains                 (const GdkRectangle  *rectangle,
-							    int                  x,
-							    int                  y);
 gboolean            eel_gdk_rectangle_contains_rectangle   (GdkRectangle         outer,
 							    GdkRectangle         inner);
-void                eel_rectangle_inset                    (GdkRectangle        *rectangle,
-							    int                  x,
-							    int                  y);
 
 
 /* A basic operation we use for drawing gradients is interpolating two colors.*/
